<?php

namespace OrganizationsManagement\Repository;

use Doctrine\ORM\EntityManager;
use OrganizationsManagement\Util\InstanceProvider;

class DataExportation {
    /** @var EntityManager **/
    protected $entityManager;

    public function __construct(){
        $this->entityManager = InstanceProvider::getDBConnection()->getOrgEntityManager(null, true);
    }

    public function setEntityManager(EntityManager $entityManager) {
        $this->entityManager = $entityManager;
    }

    /**
     * @param $tableName
     * @param $dbUser
     * @return array
     */
    public function getTableColumns($tableName, $dbUser){
        $query = "SELECT COLUMN_NAME
                    FROM ALL_TAB_COLUMNS
                   WHERE TABLE_NAME = :TABLE_NAME
                     AND OWNER = :OWNER
                     AND DATA_TYPE NOT IN ('BLOB', 'LONG RAW')";

        $params = array( 'TABLE_NAME' => $tableName, 'OWNER' => $dbUser );
        return $this->entityManager->getConnection()->fetchAll($query, $params);
    }

    /**
     * @param $originOrg
     * @param $tableName
     * @param $originDbUser
     * @param $destinyDbUser
     * @param $columns
     * @param $columnValues
     * @param $extraFilter
     * @return \Doctrine\DBAL\Driver\Statement
     */
    public function exportTable($originOrg, $tableName, $originDbUser, $destinyDbUser, $columns, $columnValues, $extraFilter = ''){
        $query = "INSERT INTO $destinyDbUser.$tableName($columns)
                              (SELECT $columnValues
                                 FROM $originDbUser.$tableName
                                WHERE NRORG = $originOrg
                                $extraFilter)";

        return $this->entityManager->getConnection()->executeQuery($query);
    }

    /**
     * @param $destinyOrg
     * @param $tableName
     * @param $destinyDbUser
     * @return \Doctrine\DBAL\Driver\Statement
     */
    public function revertTableExportation($destinyOrg, $tableName, $destinyDbUser) {
        $query = "DELETE
                    FROM $destinyDbUser.$tableName
                   WHERE NRORG = $destinyOrg";

        return $this->entityManager->getConnection()->executeQuery($query);
    }

    /**
     * @param $tableName
     * @param $dbUser
     * @param $orgId
     * @return array
     */
    public function getTableRegisters($tableName, $dbUser, $orgId) {
        $query = "SELECT COUNT(*) AS COUNT
                    FROM $dbUser.$tableName
                   WHERE NRORG = $orgId";

        return $this->entityManager->getConnection()->fetchAll($query)[0];
    }

    /**
     * @param $dbUser
     * @param $sequenceName
     * @return array
     */
    public function getSequenceLastNumber($dbUser, $sequenceName) {
        $query = "SELECT LAST_NUMBER
                    FROM ALL_SEQUENCES
                   WHERE SEQUENCE_OWNER = upper('$dbUser')
                     AND SEQUENCE_NAME = upper('$sequenceName')";

        $result = $this->entityManager->getConnection()->fetchAll($query);
        return !empty($result) ? $result[0] : $result;
    }

    /**
     * @param $dbUser
     * @param $sequenceName
     * @param $sequenceValue
     * @return \Doctrine\DBAL\Driver\Statement
     */
    public function callSequenceNewValueProcedure($dbUser, $sequenceName, $sequenceValue) {
        $query = "CALL $dbUser.SEQUENCE_NEWVALUE('$dbUser', '$sequenceName', $sequenceValue)";

        return $this->entityManager->getConnection()->executeQuery($query);
    }

    /**
     * @param $newCodeTableName
     * @param $originOrg
     * @param $destinyOrg
     * @param $sequential
     * @param $originDbUser
     * @param $destinyDbUser
     * @return \Doctrine\DBAL\Driver\Statement
     */
    public function updateNewCode($newCodeTableName, $originOrg, $destinyOrg, $sequential, $originDbUser, $destinyDbUser){
        $query = "UPDATE $destinyDbUser.$newCodeTableName
                     SET NRSEQUENCIAL = (SELECT MAX(NRSEQUENCIAL)
                                           FROM $originDbUser.NOVOCODIGO
                                          WHERE CDCONTADOR = '$sequential'
                                            AND NRORG = $originOrg)
                   WHERE CDCONTADOR = '$sequential'
                     AND NRORG = $destinyOrg";

        return $this->entityManager->getConnection()->executeQuery($query);
    }
}