<?php
namespace OrganizationsManagement\Service;

use Doctrine\ORM\EntityManager;
use OrganizationsManagement\Util\InstanceProvider;
use OrganizationsManagement\Util\Utilities;
use Teknisa\Model\Teknisa\Repositories;

class NotificationServices
{
    
     /**
     * @var EntityManager
     */
    protected $entityManager;
    /** @var TeknisaEnvironment **/
    
    public function __construct(EntityManager $entityManager)
    {
        $this->entityManager = $entityManager;
    }
    
    public function findNotificationServices($conditions)
    {
        $notificationServiceRepository = InstanceProvider::getRepository()->getNotificationServices();
        $environment = InstanceProvider::getEnvironment();
        $filters = InstanceProvider::getUtilities()->createQueryFiltered($conditions);
        $currentOrganizationId = $environment->getCurrentOrganizationId();
        return $notificationServiceRepository->findNotificationServices($currentOrganizationId,$filters);
    }
    
    public function saveNotificationServices($id, $idativo, $dsserviconotif, $nmserviconotif)
    {
        $connection = $this->entityManager->getConnection();
        $notificationServiceRepository = InstanceProvider::getRepository()->getNotificationServices();
        $notificationServiceFactory = InstanceProvider::getFactory()->getNotificationServices();
        $environment = InstanceProvider::getEnvironment();
        $currentOrganizationId = $environment->getCurrentOrganizationId();
        $currentUserId = $environment->getCurrentUserId();
        $dateNow = new \DateTime();
        $notificationServiceEntity = null;
        
        try {
            $connection->beginTransaction();
            if ($id) {
                $notificationServiceEntity = $notificationServiceRepository->find($id);
            }
            $notificationServiceEntity = $notificationServiceFactory->save($notificationServiceEntity, $idativo, $dsserviconotif, $nmserviconotif, $currentOrganizationId, $currentUserId, $dateNow);
            $this->entityManager->persist($notificationServiceEntity);
            $this->entityManager->flush();
            $connection->commit();
            return array('ID' => $notificationServiceEntity->getId() );
                
        } catch (Exception $ex) {
            $connection->rollback();
            throw $ex;
        }
    }
    
    public function deleteNotificationServices($id)
    {
        $connection = $this->entityManager->getConnection();
        try {
            $connection->beginTransaction();
            $notificationServiceEntity = $this->entityManager->find(Utilities::TEKNISA_ENTITY_DIR.'OmServicoNotificacao', $id);
            $this->entityManager->remove($notificationServiceEntity);
            $this->entityManager->flush();
            $connection->commit();
        } catch (Exception $ex) {
            $connection->rollback();
            throw $ex;
        }
    }
    
     public function findNotificationServicesApp($conditions)
    {
        $notificationServicesAppRepository = InstanceProvider::getRepository()->getNotificationServicesApp();
        $environment = InstanceProvider::getEnvironment();
        $filters = InstanceProvider::getUtilities()->createQueryFiltered($conditions);
        $currentOrganizationId = $environment->getCurrentOrganizationId();
        return $notificationServicesAppRepository->findNotificationServicesApp($currentOrganizationId,$filters);
    }
    
    public function saveNotificationServicesApp($id, $idativo, $nmservnotifappparam, $dsservnotifappparam, $nrserviconotif_id)
    {
        $connection = $this->entityManager->getConnection();
        $notificationServiceAppFactory = InstanceProvider::getFactory()->getNotificationServicesApp();
        $notificationServiceAppRepository = InstanceProvider::getRepository()->getNotificationServicesApp();
        $environment = InstanceProvider::getEnvironment();
        $currentOrganizationId = $environment->getCurrentOrganizationId();
        $currentUserId = $environment->getCurrentUserId();
        $dateNow = new \DateTime;
        $notificationServiceAppEntity =  null;
        
        try {
            $connection->beginTransaction();
            if ($id) {
                $notificationServiceAppEntity =  $notificationServiceAppRepository->find($id);
            }
            $notificationServiceAppEntity = $notificationServiceAppFactory->save($notificationServiceAppEntity, $idativo, $nmservnotifappparam, $dsservnotifappparam, $nrserviconotif_id, $currentOrganizationId, $currentUserId, $dateNow);
            $this->entityManager->persist($notificationServiceAppEntity);
            $this->entityManager->flush();
            $connection->commit();
            return array('ID' => $notificationServiceAppEntity->getId());
        } catch (Exception $ex) {
            $connection->rollback();
            throw $ex;
        }
    }
    
    public function deleteNotificationServicesApp($id)
    {
        $connection = $this->entityManager->getConnection();
        try {
            $connection->beginTransaction();
            $notificationServiceAppEntity = $this->entityManager->find(Utilities::TEKNISA_ENTITY_DIR.'OmServicoNotifAppParam', $id);
            $this->entityManager->remove($notificationServiceAppEntity);
            $this->entityManager->flush();
            $connection->commit();            
        } catch (Exception $ex) {
            $connection->rollback();
            throw $ex;
        }
    }
    
    public function findNotificationServicesDev($conditions)
    {
        $notificationServicesDevRepository = InstanceProvider::getRepository()->getNotificationServicesDev();
        $environment = InstanceProvider::getEnvironment();
        $filters = InstanceProvider::getUtilities()->createQueryFiltered($conditions);
        $currentOrganizationId = $environment->getCurrentOrganizationId();
        return $notificationServicesDevRepository->findNotificationServicesDev($currentOrganizationId,$filters);
    }
    
    public function saveNotificationServicesDev($id, $idativo, $nmservnotifdispparam, $dsservnotifdispparam, $nrserviconotif_id)
    {
        $connection = $this->entityManager->getConnection();
        $notificationServiceDevFactory = InstanceProvider::getFactory()->getNotificationServicesDev();
        $notificationServiceDevRepository = InstanceProvider::getRepository()->getNotificationServicesDev();
        $environment = InstanceProvider::getEnvironment();
        $currentOrganizationId = $environment->getCurrentOrganizationId();
        $currentUserId = $environment->getCurrentUserId();
        $dateNow = new \DateTime;
        $notificationServiceDevEntity =  null;
        
        try {
            $connection->beginTransaction();
            if ($id) {
                $notificationServiceDevEntity =  $notificationServiceDevRepository->find($id);
            }
            $notificationServiceDevEntity = $notificationServiceDevFactory->save($notificationServiceDevEntity, $idativo, $nmservnotifdispparam, $dsservnotifdispparam, $nrserviconotif_id, $currentOrganizationId, $currentUserId, $dateNow);
            $this->entityManager->persist($notificationServiceDevEntity);
            $this->entityManager->flush();
            $connection->commit();

            return array('ID' => $notificationServiceDevEntity->getId());
        } catch (Exception $ex) {
            $connection->rollback();
            throw $ex;
        }
    }
    
    public function deleteNotificationServicesDev($id)
    {
        $connection = $this->entityManager->getConnection();
        try {
            $connection->beginTransaction();
            $notificationServiceDevEntity = $this->entityManager->find(Utilities::TEKNISA_ENTITY_DIR.'OmServicoNotifDispParam', $id);
            $this->entityManager->remove($notificationServiceDevEntity);
            $this->entityManager->flush();
            $connection->commit();            
        } catch (Exception $ex) {
            $connection->rollback();
            throw $ex;
        }

    }
}